@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from collections import defaultdict
+from html import escape
 import json
 from pathlib import Path
 import re
@@ -10,16 +11,18 @@ from typing import Any, DefaultDict, cast
 from docutils import nodes
 from markdown_it.token import Token
 from markdown_it.tree import SyntaxTreeNode
-from myst_parser.docutils_renderer import token_line
-from myst_parser.main import MdParserConfig, create_md_parser
-from myst_parser.sphinx_parser import MystParser
-from myst_parser.sphinx_renderer import SphinxRenderer
+from myst_parser.config.main import MdParserConfig, merge_file_level
+from myst_parser.mdit_to_docutils.base import token_line
+from myst_parser.mdit_to_docutils.sphinx_ import SphinxRenderer, create_warning
+from myst_parser.parsers.mdit import create_md_parser
+from myst_parser.parsers.sphinx_ import MystParser
 import nbformat
 from sphinx.application import Sphinx
 from sphinx.environment import BuildEnvironment
 from sphinx.environment.collectors import EnvironmentCollector
 from sphinx.transforms.post_transforms import SphinxPostTransform
 from sphinx.util import logging as sphinx_logging
+from sphinx.util.docutils import SphinxTranslator
 
 from myst_nb._compat import findall
 from myst_nb.core.config import NbParserConfig
@@ -72,6 +75,7 @@ class Parser(MystParser):
 
         # get markdown parsing configuration
         md_config: MdParserConfig = self.env.myst_config
+
         # get notebook rendering configuration
         nb_config: NbParserConfig = self.env.mystnb_config
 
@@ -82,6 +86,14 @@ class Parser(MystParser):
             return super().parse(inputstring, document)
         notebook = nb_reader.read(inputstring)
 
+        # update the global markdown config with the file-level config
+        warning = lambda wtype, msg: create_warning(  # noqa: E731
+            document, msg, line=1, append_to=document, subtype=wtype
+        )
+        nb_reader.md_config = merge_file_level(
+            nb_reader.md_config, notebook.metadata, warning
+        )
+
         # potentially replace kernel name with alias
         kernel_name = notebook.metadata.get("kernelspec", {}).get("name", None)
         if kernel_name is not None and nb_config.kernel_rgx_aliases:
@@ -310,7 +322,7 @@ class SelectMimeType(SphinxPostTransform):
         """Run the transform."""
         # get priority list for this builder
         # TODO allow for per-notebook/cell priority dicts?
-        bname = self.app.builder.name  # type: ignore
+        bname = self.app.builder.name
         priority_list = get_mime_priority(
             bname, self.config["nb_mime_priority_overrides"]
         )
@@ -462,3 +474,79 @@ class BytesEncoder(json.JSONEncoder):
         if isinstance(obj, bytes):
             return obj.decode("ascii")
         return json.JSONEncoder.default(self, obj)
+
+
+class HideCodeCellNode(nodes.Element):
+    """Node for hiding cell input."""
+
+    @classmethod
+    def add_to_app(cls, app: Sphinx):
+        app.add_node(cls, html=(visit_HideCellInput, depart_HideCellInput))
+
+
+def visit_HideCellInput(self: SphinxTranslator, node: HideCodeCellNode):
+    classes = " ".join(node["classes"])
+    self.body.append(f'<details class="hide {classes}">\n')
+    self.body.append('<summary aria-label="Toggle hidden content">\n')
+    self.body.append(f'<span class="collapsed">{escape(node["prompt_show"])}</span>\n')
+    self.body.append(f'<span class="expanded">{escape(node["prompt_hide"])}</span>\n')
+    self.body.append("</summary>\n")
+
+
+def depart_HideCellInput(self: SphinxTranslator, node: HideCodeCellNode):
+    self.body.append("</details>\n")
+
+
+class HideInputCells(SphinxPostTransform):
+    """Hide input cells in the HTML output."""
+
+    default_priority = 199
+    formats = ("html",)
+
+    def run(self, **kwargs):
+
+        for node in findall(self.document)(nodes.container):
+
+            if (
+                node.get("nb_element") == "cell_code"
+                and node.get("hide_mode")
+                and node.children
+            ):
+                hide_mode = node.get("hide_mode")
+                has_input = node.children[0].get("nb_element") == "cell_code_source"
+                has_output = node.children[-1].get("nb_element") == "cell_code_output"
+
+                # if we have the code source (input) element,
+                # and we are collapsing the input or input+output
+                # then we attach the "collapse button" above the input
+                if has_input and hide_mode == "input":
+                    wrap_node = HideCodeCellNode(
+                        prompt_show=node["prompt_show"].replace("{type}", "source"),
+                        prompt_hide=node["prompt_hide"].replace("{type}", "source"),
+                    )
+                    wrap_node["classes"].append("above-input")
+                    code = node.children[0]
+                    wrap_node.append(code)
+                    node.replace(code, wrap_node)
+
+                elif has_input and hide_mode == "all":
+                    wrap_node = HideCodeCellNode(
+                        prompt_show=node["prompt_show"].replace("{type}", "content"),
+                        prompt_hide=node["prompt_hide"].replace("{type}", "content"),
+                    )
+                    wrap_node["classes"].append("above-input")
+                    wrap_node.extend(node.children)
+                    node.children = [wrap_node]
+
+                # if we don't have the code source (input) element,
+                # or are only hiding the output,
+                # then we place the "collapse button" above the output
+                elif has_output and hide_mode in ("output", "all"):
+                    wrap_node = HideCodeCellNode(
+                        prompt_show=node["prompt_show"].replace("{type}", "outputs"),
+                        prompt_hide=node["prompt_hide"].replace("{type}", "outputs"),
+                    )
+                    wrap_node["classes"].append("above-output")
+                    output = node.children[-1]
+                    wrap_node.append(output)
+                    node.replace(output, wrap_node)
